kombu.simple — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.simple

Simple interface.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

- Persistent
- Buffer

## Persistent

class `kombu.simple.` `SimpleQueue`(channel, name, no_ack=None, queue_opts=None, exchange_opts=None, serializer=None, compression=None, **kwargs)
  `channel`

    Current channel

  `producer`

    `Producer` used to publish messages.

  `consumer`

    `Consumer` used to receive messages.

  `no_ack`

    flag to enable/disable acknowledgements.

  `queue`

    `Queue` to consume from (if consuming).

  `queue_opts`

    > Additional options for the queue declaration.

    `exchange_opts`

      Additional options for the exchange declaration.

  `get`(block=True, timeout=None)
  `get_nowait`()
  `put`(message, serializer=None, headers=None, compression=None, routing_key=None, **kwargs)
  `clear`()
  `__len__`()

    len(self) -> self.qsize()

  `qsize`()
  `close`()

## Buffer

class `kombu.simple.` `SimpleBuffer`(channel, name, no_ack=None, queue_opts=None, exchange_opts=None, serializer=None, compression=None, **kwargs)
  `channel`

    Current channel

  `producer`

    `Producer` used to publish messages.

  `consumer`

    `Consumer` used to receive messages.

  `no_ack`

    flag to enable/disable acknowledgements.

  `queue`

    `Queue` to consume from (if consuming).

  `queue_opts`

    > Additional options for the queue declaration.

    `exchange_opts`

      Additional options for the exchange declaration.

  `get`(block=True, timeout=None)
  `get_nowait`()
  `put`(message, serializer=None, headers=None, compression=None, routing_key=None, **kwargs)
  `clear`()
  `__len__`()

    len(self) -> self.qsize()

  `qsize`()
  `close`()

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »